@@ -15,7 +15,7 @@ from .cos_matrix2 import cos_matrix2  # noqa: F401
 from .with_func_attrs import with_func_attrs  # noqa: F401
 from .report_time import report_time  # noqa: F401
 from .langcode_to_tmxcode import langcode_to_tmxcode  # noqa: F401
-from .spiiner import Spinner  # noqa: F401
+from .spinner import Spinner  # noqa: F401
 
 
 # sys.path.insert(0, '..')
@@ -34,5 +34,5 @@ for elm in Path(__file__).parent.glob('*.py'):
 # version__ = '0.0.5'
 # version__ = '0.0.6'
 # version__ = '0.0.7'
-__version__ = '0.0.9'
+__version__ = '0.1.0'
 VERSION = tuple(__version__.split('.'))
