@@ -18,10 +18,13 @@ import os
 import pathlib
 from pathlib import Path
 import tempfile
+
 import subprocess
 import platform
+
 # import cchardet
 import chardet
+import webbrowser
 
 # from nose.tools import (eq_, with_setup)
 
@@ -31,9 +34,16 @@ from logzero import logger
 
 # def savetofile(text, filename='out.html', encoding='utf-8', start=False):
 # def save_tempfile(text, filename=None, encoding='ascii', start=True):
-def save_tempfile(text, filename=None, encoding='utf-8', start=True):  # pylint: disable=too-many-branches, too-many-return-statements
-    """
-    Save text (str) to file (default to tmp.txt) or filepath (Path(str))
+def save_tempfile(
+    text,
+    filename=None,
+    encoding='utf-8',
+    start=True,
+    browser=False,
+):  # pylint: disable=too-many-branches, too-many-return-statements
+    """Save text (str) to file (default to tmp.txt) or filepath (Path(str)).
+
+    if brwoser set to True/1, attempt to use system default open method usin webbrowser package.
     """
     if filename is None:
         filename = tempfile.NamedTemporaryFile('w', delete=False, suffix='.html').name
@@ -79,6 +89,13 @@ def save_tempfile(text, filename=None, encoding='utf-8', start=True):  # pylint:
         # logger.info("\n\tSaved to %s (encoding: %s)", str(fpath), encoding)
         logger.info("\n\tSaved to %s", str(fpath))
 
+    if browser:
+        try:
+            webbrowser.open(str(fpath))
+            return fpath.__str__()
+        except Exception as exc:
+            logger.warning("Unable to start webbrowser.open: %s", exc)
+
     if start:
         # modi
 
